@@ -18,33 +18,35 @@
 
 namespace frc2 {
 /**
- * A CommandGroup that runs a set of commands in parallel, ending when the last
- * command ends.
+ * A command composition that runs a set of commands in parallel, ending when
+ * the last command ends.
  *
- * <p>As a rule, CommandGroups require the union of the requirements of their
- * component commands.
+ * <p>The rules for command compositions apply: command instances that are
+ * passed to it are owned by the composition and cannot be added to any other
+ * composition or scheduled individually, and the composition requires all
+ * subsystems its components require.
  */
 class ParallelCommandGroup
     : public CommandGroupBase {
  public:
   /**
-   * Creates a new ParallelCommandGroup.  The given commands will be executed
+   * Creates a new ParallelCommandGroup. The given commands will be executed
    * simultaneously. The command group will finish when the last command
-   * finishes.  If the CommandGroup is interrupted, only the commands that are
+   * finishes. If the composition is interrupted, only the commands that are
    * still running will be interrupted.
    *
-   * @param commands the commands to include in this group.
+   * @param commands the commands to include in this composition.
    */
   explicit ParallelCommandGroup(
       std::vector<std::shared_ptr<Command>>&& commands);
 
   /**
-   * Creates a new ParallelCommandGroup.  The given commands will be executed
+   * Creates a new ParallelCommandGroup. The given commands will be executed
    * simultaneously. The command group will finish when the last command
-   * finishes.  If the CommandGroup is interrupted, only the commands that are
+   * finishes. If the composition is interrupted, only the commands that are
    * still running will be interrupted.
    *
-   * @param commands the commands to include in this group.
+   * @param commands the commands to include in this composition.
    */
   template <class... Types,
             typename = std::enable_if_t<std::conjunction_v<
@@ -55,7 +57,7 @@ class ParallelCommandGroup
 
   ParallelCommandGroup(ParallelCommandGroup&& other) = default;
 
-  // No copy constructors for commandgroups
+  // No copy constructors for command groups
   ParallelCommandGroup(const ParallelCommandGroup&) = delete;
 
   // Prevent template expansion from emulating copy ctor
@@ -72,21 +74,26 @@ class ParallelCommandGroup
     AddCommands(std::move(foo));
   }
 
-  void Initialize() override;
+  void Initialize() final;
 
-  void Execute() override;
+  void Execute() final;
 
-  void End(bool interrupted) override;
+  void End(bool interrupted) final;
 
-  bool IsFinished() override;
+  bool IsFinished() final;
 
   bool RunsWhenDisabled() const override;
 
+  Command::InterruptionBehavior GetInterruptionBehavior() const override;
+
  public:
   void AddCommands(std::vector<std::shared_ptr<Command>>&& commands) final;
+
  private:
   std::vector<std::pair<std::shared_ptr<Command>, bool>> m_commands;
   bool m_runWhenDisabled{true};
+  Command::InterruptionBehavior m_interruptBehavior{
+      Command::InterruptionBehavior::kCancelIncoming};
   bool isRunning = false;
 };
 }  // namespace frc2
