@@ -6,11 +6,13 @@
 
 #include <functional>
 #include <initializer_list>
+#include <span>
 #include <utility>
 
-#include <wpi/ArrayRef.h>
+#include <wpi/deprecated.h>
 
 #include "Trigger.h"
+#include "frc2/command/CommandPtr.h"
 
 namespace frc2 {
 class Command;
@@ -25,14 +27,18 @@ class Button : public Trigger {
   /**
    * Create a new button that is pressed when the given condition is true.
    *
-   * @param isActive Whether the button is pressed.
+   * @param isPressed Whether the button is pressed.
+   * @deprecated Replace with Trigger
    */
+  WPI_DEPRECATED("Replace with Trigger")
   explicit Button(std::function<bool()> isPressed);
 
   /**
    * Create a new button that is pressed active (default constructor) - activity
    *  can be further determined by subclass code.
+   * @deprecated Replace with Trigger
    */
+  WPI_DEPRECATED("Replace with Trigger")
   Button() = default;
 
   /**
@@ -41,10 +47,11 @@ class Button : public Trigger {
    * of the command.
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The trigger, for chained calls.
+   * @deprecated Replace with Trigger::OnTrue()
    */
-  Button WhenPressed(std::shared_ptr<Command> command, bool interruptible = true);
+  WPI_DEPRECATED("Replace with Trigger#OnTrue()")
+  Button WhenPressed(std::shared_ptr<Command> command);
 
   /**
    * Binds a command to start when the button is pressed.  Transfers
@@ -53,13 +60,14 @@ class Button : public Trigger {
    * *copied.*
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The trigger, for chained calls.
+   * @deprecated Replace with Trigger::OnTrue()
    */
   template <class T, typename = std::enable_if_t<std::is_base_of_v<
                          Command, std::remove_reference_t<T>>>>
-  Button WhenPressed(T&& command, bool interruptible = true) {
-    WhenActive(std::forward<T>(command), interruptible);
+  WPI_DEPRECATED("Replace with Trigger#OnTrue()")
+  Button WhenPressed(T&& command) {
+    WhenActive(std::forward<T>(command));
     return *this;
   }
 
@@ -68,18 +76,24 @@ class Button : public Trigger {
    *
    * @param toRun the runnable to execute.
    * @param requirements the required subsystems.
+   * @deprecated Replace with Trigger::OnTrue(cmd::RunOnce())
    */
+   /*
+  WPI_DEPRECATED("Replace with Trigger#OnTrue(cmd::RunOnce())")
   Button WhenPressed(std::function<void()> toRun,
                      std::initializer_list<std::shared_ptr<Subsystem>> requirements);
+  */
 
   /**
    * Binds a runnable to execute when the button is pressed.
    *
    * @param toRun the runnable to execute.
    * @param requirements the required subsystems.
+   * @deprecated Replace with Trigger::OnTrue(cmd::RunOnce())
    */
+  WPI_DEPRECATED("Replace with Trigger#OnTrue(cmd::RunOnce())")
   Button WhenPressed(std::function<void()> toRun,
-                     wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+                     std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Binds a command to be started repeatedly while the button is pressed, and
@@ -87,10 +101,11 @@ class Button : public Trigger {
    * users are responsible for the lifespan of the command.
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::WhileTrue(command.Repeatedly())
    */
-  Button WhileHeld(std::shared_ptr<Command> command, bool interruptible = true);
+  WPI_DEPRECATED("Replace with Trigger#WhileTrue(command.Repeatedly())")
+  Button WhileHeld(std::shared_ptr<Command> command);
 
   /**
    * Binds a command to be started repeatedly while the button is pressed, and
@@ -99,13 +114,14 @@ class Button : public Trigger {
    * will be *moved*, lvalue refs will be *copied.*
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::WhileTrue(command.Repeatedly())
    */
   template <class T, typename = std::enable_if_t<std::is_base_of_v<
                          Command, std::remove_reference_t<T>>>>
-  Button WhileHeld(T&& command, bool interruptible = true) {
-    WhileActiveContinous(std::forward<T>(command), interruptible);
+  WPI_DEPRECATED("Replace with Trigger#WhileTrue(command.Repeatedly())")
+  Button WhileHeld(T&& command) {
+    WhileActiveContinous(std::forward<T>(command));
     return *this;
   }
 
@@ -114,18 +130,24 @@ class Button : public Trigger {
    *
    * @param toRun the runnable to execute.
    * @param requirements the required subsystems.
+   * @deprecated Replace with Trigger::WhileTrue(cmd::Run())
    */
+   /*
+  WPI_DEPRECATED("Replace with Trigger#WhileTrue(cmd::Run())")
   Button WhileHeld(std::function<void()> toRun,
                    std::initializer_list<std::shared_ptr<Subsystem>> requirements);
+  */
 
   /**
    * Binds a runnable to execute repeatedly while the button is pressed.
    *
    * @param toRun the runnable to execute.
    * @param requirements the required subsystems.
+   * @deprecated Replace with Trigger::WhileTrue(cmd::Run())
    */
+  WPI_DEPRECATED("Replace with Trigger#WhileTrue(cmd::Run())")
   Button WhileHeld(std::function<void()> toRun,
-                   wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+                   std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Binds a command to be started when the button is pressed, and canceled
@@ -133,10 +155,11 @@ class Button : public Trigger {
    * responsible for the lifespan of the command.
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::WhileTrue()
    */
-  Button WhenHeld(std::shared_ptr<Command> command, bool interruptible = true);
+  WPI_DEPRECATED("Replace with Trigger#WhileTrue()")
+  Button WhenHeld(std::shared_ptr<Command> command);
 
   /**
    * Binds a command to be started when the button is pressed, and canceled
@@ -145,13 +168,14 @@ class Button : public Trigger {
    * *moved*, lvalue refs will be *copied.*
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::WhileTrue()
    */
   template <class T, typename = std::enable_if_t<std::is_base_of_v<
                          Command, std::remove_reference_t<T>>>>
-  Button WhenHeld(T&& command, bool interruptible = true) {
-    WhileActiveOnce(std::forward<T>(command), interruptible);
+  WPI_DEPRECATED("Replace with Trigger#WhileTrue()")
+  Button WhenHeld(T&& command) {
+    WhileActiveOnce(std::forward<T>(command));
     return *this;
   }
 
@@ -161,10 +185,11 @@ class Button : public Trigger {
    * of the command.
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::OnFalse()
    */
-  Button WhenReleased(std::shared_ptr<Command> command, bool interruptible = true);
+  WPI_DEPRECATED("Replace with Trigger#OnFalse()")
+  Button WhenReleased(std::shared_ptr<Command> command);
 
   /**
    * Binds a command to start when the button is pressed.  Transfers
@@ -173,13 +198,14 @@ class Button : public Trigger {
    * *copied.*
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::OnFalse()
    */
   template <class T, typename = std::enable_if_t<std::is_base_of_v<
                          Command, std::remove_reference_t<T>>>>
-  Button WhenReleased(T&& command, bool interruptible = true) {
-    WhenInactive(std::forward<T>(command), interruptible);
+  WPI_DEPRECATED("Replace with Trigger#OnFalse()")
+  Button WhenReleased(T&& command) {
+    WhenInactive(std::forward<T>(command));
     return *this;
   }
 
@@ -188,18 +214,24 @@ class Button : public Trigger {
    *
    * @param toRun the runnable to execute.
    * @param requirements the required subsystems.
+   * @deprecated Replace with Trigger::OnFalse(cmd::RunOnce())
    */
+   /*
+  WPI_DEPRECATED("Replace with Trigger#OnFalse(cmd::RunOnce())")
   Button WhenReleased(std::function<void()> toRun,
                       std::initializer_list<std::shared_ptr<Subsystem>> requirements);
+  */
 
   /**
    * Binds a runnable to execute when the button is released.
    *
    * @param toRun the runnable to execute.
    * @param requirements the required subsystems.
+   * @deprecated Replace with Trigger::OnFalse(cmd::RunOnce())
    */
+  WPI_DEPRECATED("Replace with Trigger#OnFalse(cmd::RunOnce())")
   Button WhenReleased(std::function<void()> toRun,
-                      wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+                      std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Binds a command to start when the button is pressed, and be canceled when
@@ -207,25 +239,27 @@ class Button : public Trigger {
    * responsible for the lifespan of the command.
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::ToggleOnTrue()
    */
-  Button ToggleWhenPressed(std::shared_ptr<Command> command, bool interruptible = true);
+  WPI_DEPRECATED("Replace with Trigger#ToggleOnTrue()")
+  Button ToggleWhenPressed(std::shared_ptr<Command> command);
 
   /**
    * Binds a command to start when the button is pressed, and be canceled when
-   * it is pessed again.  Transfers command ownership to the button scheduler,
+   * it is pressed again.  Transfers command ownership to the button scheduler,
    * so the user does not have to worry about lifespan - rvalue refs will be
    * *moved*, lvalue refs will be *copied.*
    *
    * @param command The command to bind.
-   * @param interruptible Whether the command should be interruptible.
    * @return The button, for chained calls.
+   * @deprecated Replace with Trigger::ToggleOnTrue()
    */
   template <class T, typename = std::enable_if_t<std::is_base_of_v<
                          Command, std::remove_reference_t<T>>>>
-  Button ToggleWhenPressed(T&& command, bool interruptible = true) {
-    ToggleWhenActive(std::forward<T>(command), interruptible);
+  WPI_DEPRECATED("Replace with Trigger#ToggleOnTrue()")
+  Button ToggleWhenPressed(T&& command) {
+    ToggleWhenActive(std::forward<T>(command));
     return *this;
   }
 
@@ -236,7 +270,9 @@ class Button : public Trigger {
    *
    * @param command The command to bind.
    * @return The button, for chained calls.
+   * @deprecated Pass this as a command end condition with Until() instead.
    */
+  WPI_DEPRECATED("Pass this as a command end condition with Until() instead.")
   Button CancelWhenPressed(std::shared_ptr<Command> command);
 };
 }  // namespace frc2
